@@ -5,10 +5,10 @@ export class BookAppItem {
     }
 
     init() {
-        this.app.routes['books'] = {
+        this.app.routes["books"] = {
             requireLogin: true,
             open: pathnameParts => {
-                const path = ('/' + pathnameParts.slice(2).join('/')).replace(/\/?$/, '/')
+                const path = ("/" + pathnameParts.slice(2).join("/")).replace(/\/?$/, "/")
                 return import("../../modules/books").then(({BookOverview}) => new BookOverview(this.app.config, path))
             },
             dbTables: {
